@@ -225,7 +225,14 @@ log_create_pathname (char *servname, char *channame, char *netname)
 	strftime (fnametime, sizeof (fnametime), fname, tm);
 
 	/* create final path/filename */
-	snprintf (fname, sizeof (fname), "%s/xchatlogs/%s", get_xdir_utf8 (), fnametime);
+#ifdef WIN32
+	if (fnametime[0] == '/' || (fnametime[0] >= 'A' && fnametime[1] == ':'))
+#else
+	if (fnametime[0] == '/')	/* is it fullpath already? */
+#endif
+		snprintf (fname, sizeof (fname), "%s", fnametime);
+	else
+		snprintf (fname, sizeof (fname), "%s/xchatlogs/%s", get_xdir_utf8 (), fnametime);
 
 	/* now we need it in FileSystem encoding */
 	fs = xchat_filename_from_utf8 (fname, -1, 0, 0, 0);
@@ -641,6 +648,7 @@ static char * const pevt_chanmsg_help[] = {
 static char * const pevt_privmsg_help[] = {
 	N_("Nickname"),
 	N_("The message"),
+	N_("Identified text")
 };
 
 static char * const pevt_changenick_help[] = {
@@ -705,12 +713,6 @@ static char * const pevt_channotice_help[] = {
 	N_("The message"),
 };
 
-static char * const pevt_dprivmsg_help[] = {
-	N_("Nickname"),
-	N_("The message"),
-	N_("Identified text"),
-};
-
 static char * const pevt_uchangenick_help[] = {
 	N_("Old nickname"),
 	N_("New nickname"),
@@ -1115,7 +1117,7 @@ pevent_load_defaults ()
 			free (pntevts_text[i]);
 
 		/* make-te.c sets this 128 flag (DON'T call gettext() flag) */
-		if (te[i].num_args & 128)
+		if (te[i].num_args & 128 || strcmp (_(te[i].def), ""))
 			pntevts_text[i] = strdup (te[i].def);
 		else
 			pntevts_text[i] = strdup (_(te[i].def));
@@ -1139,7 +1141,7 @@ pevent_make_pntevts ()
 			fe_message (out, FE_MSG_WARN);
 			free (pntevts_text[i]);
 			/* make-te.c sets this 128 flag (DON'T call gettext() flag) */
-			if (te[i].num_args & 128)
+			if (te[i].num_args & 128 || strcmp (_(te[i].def), ""))
 				pntevts_text[i] = strdup (te[i].def);
 			else
 				pntevts_text[i] = strdup (_(te[i].def));
@@ -1319,7 +1321,7 @@ pevent_check_all_loaded ()
 			snprintf(out, sizeof(out), "The data for event %s failed to load. Reverting to defaults.\nThis may be because a new version of XChat is loading an old config file.\n\nCheck all print event texts are correct", evtnames[i]);
 			   gtkutil_simpledialog(out); */
 			/* make-te.c sets this 128 flag (DON'T call gettext() flag) */
-			if (te[i].num_args & 128)
+			if (te[i].num_args & 128 || strcmp (_(te[i].def), ""))
 				pntevts_text[i] = strdup (te[i].def);
 			else
 				pntevts_text[i] = strdup (_(te[i].def));
@@ -1665,6 +1667,18 @@ text_emit (int index, session *sess, char *a, char *b, char *c, char *d)
 		display_event (sess, index, word, stripcolor_args);
 }
 
+char *
+text_find_format_string (char *name)
+{
+	int i = 0;
+
+	i = pevent_find (name, &i);
+	if (i >= 0)
+		return pntevts_text[i];
+
+	return NULL;
+}
+
 int
 text_emit_by_name (char *name, session *sess, char *a, char *b, char *c, char *d)
 {
