@@ -36,7 +36,10 @@ connect_dialog_finalize (GObject *object)
 {
 	ConnectDialog *dialog = (ConnectDialog *) object;
 
-	g_object_unref (dialog->server_store);
+	if (dialog->server_store) {
+		g_object_unref (dialog->server_store);
+		dialog->server_store = NULL;
+	}
 
 	((GObjectClass *) parent_class)->finalize (object);
 }
@@ -61,44 +64,45 @@ selection_changed (GtkTreeSelection *select, ConnectDialog *dialog)
 static void
 dialog_response (ConnectDialog *dialog, gint response, gpointer data)
 {
-	if (response == GTK_RESPONSE_OK) {
-		GtkTreeModel *model;
-		GtkTreeIter iter;
-		GtkTreeSelection *select;
+	if (response != GTK_RESPONSE_OK) {
+		gtk_widget_destroy (GTK_WIDGET (dialog));
+		return;
+	}
 
-		select = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->server_list));
-		if (gtk_tree_selection_get_selected (select, &model, &iter)) {
-			session *s = NULL;
-			ircnet *net;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
 
-			// If the currently selected server is not connected, use it
-			// for the new session.
-			if (gui.current_session &&
-			    (gui.current_session->server == NULL ||
-			     gui.current_session->server->connected == FALSE)) {
-				s = gui.current_session;
-			}
+	GtkTreeSelection *select = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->server_list));
+	if (gtk_tree_selection_get_selected (select, &model, &iter)) {
+		session *s = NULL;
+		ircnet *net;
 
-			// Make sure that this network isn't already connected.
-			gtk_tree_model_get (model, &iter, 1, &net, -1);
-			gboolean found = FALSE;
-			for (GSList *i = sess_list; i; i = g_slist_next (i)) {
-				session *sess = (session *)(i->data);
-				if (sess->type == SESS_SERVER &&
-				    sess->server != NULL &&
-				    sess->server->network == net &&
-				    (sess->server->connected || sess->server->connecting)) {
-					found = TRUE;
-				}
-			}
-
-			if (!found) {
-				servlist_connect (s, net, TRUE);
-			}
-
-			gtk_widget_destroy (GTK_WIDGET (dialog));
+		// If the currently selected server is not connected, use it
+		// for the new session.
+		if (gui.current_session &&
+		    (gui.current_session->server == NULL ||
+		     gui.current_session->server->connected == FALSE)) {
+			s = gui.current_session;
 		}
-	} else {
+
+		// Make sure that this network isn't already connected.
+		gtk_tree_model_get (model, &iter, 1, &net, -1);
+		gboolean found = FALSE;
+		for (GSList *i = sess_list; i; i = g_slist_next (i)) {
+			session *sess = (session *)(i->data);
+			if (sess->type == SESS_SERVER &&
+			    sess->server != NULL &&
+			    sess->server->network == net &&
+			    (sess->server->connected || sess->server->connecting)) {
+				found = TRUE;
+				break;
+			}
+		}
+
+		if (!found) {
+			servlist_connect (s, net, TRUE);
+		}
+
 		gtk_widget_destroy (GTK_WIDGET (dialog));
 	}
 }
@@ -115,26 +119,13 @@ row_activated (GtkTreeView *widget, GtkTreePath *path, GtkTreeViewColumn *column
 static void
 connect_dialog_init (ConnectDialog *dialog)
 {
-	GtkCellRenderer *renderer;
-	GtkTreeViewColumn *column;
-	GladeXML *xml;
-	GtkWidget *button;
-	GtkTreeSelection *select;
-	GtkTreeIter iter;
-	GSList *netlist;
-	ircnet *net;
-	gchar *path;
+	gchar *path = locate_data_file ("connect-dialog.glade");
+	g_assert(path != NULL);
 
-	dialog->toplevel = NULL;
+	GladeXML *xml = glade_xml_new (path, "toplevel", NULL);
+	g_assert(xml != NULL);
 
-	xml = NULL;
-	path = locate_data_file ("connect-dialog.glade");
-
-	xml = glade_xml_new (path, "toplevel", NULL);
 	g_free (path);
-	if (!xml) {
-		return;
-	}
 
 #define GW(name) ((dialog->name) = glade_xml_get_widget (xml, #name))
 	GW(toplevel);
@@ -146,11 +137,11 @@ connect_dialog_init (ConnectDialog *dialog)
 	dialog->server_store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_POINTER);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (dialog->server_list), GTK_TREE_MODEL (dialog->server_store));
 
-	renderer = gtk_cell_renderer_text_new ();
-	column = gtk_tree_view_column_new_with_attributes ("name", renderer, "text", 0, NULL);
+	GtkCellRenderer *renderer = gtk_cell_renderer_text_new ();
+	GtkTreeViewColumn *column = gtk_tree_view_column_new_with_attributes ("name", renderer, "text", 0, NULL);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (dialog->server_list), column);
 
-	button = gtk_button_new_with_mnemonic (_("C_onnect"));
+	GtkWidget *button = gtk_button_new_with_mnemonic (_("C_onnect"));
 	gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
 	gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
 	gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
@@ -159,15 +150,18 @@ connect_dialog_init (ConnectDialog *dialog)
 
 	g_signal_connect (G_OBJECT (dialog->server_list), "row-activated", G_CALLBACK (row_activated), dialog);
 
-	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->server_list));
-	g_signal_connect (G_OBJECT (select), "changed", G_CALLBACK (selection_changed), dialog);
+	g_signal_connect (
+		G_OBJECT (gtk_tree_view_get_selection (GTK_TREE_VIEW (dialog->server_list))),
+		"changed",
+		G_CALLBACK (selection_changed),
+		dialog);
 
-	netlist = network_list;
-	while (netlist) {
-		net = netlist->data;
+	for (GSList *netlist = network_list; netlist; netlist = g_slist_next (netlist)) {
+		GtkTreeIter iter;
+
+		ircnet *net = netlist->data;
 		gtk_list_store_append (dialog->server_store, &iter);
 		gtk_list_store_set (dialog->server_store, &iter, 0, net->name, 1, net, -1);
-		netlist = g_slist_next (netlist);
 	}
 
 	gtk_window_set_default_size (GTK_WINDOW (dialog), 320, 240);
@@ -203,10 +197,5 @@ connect_dialog_get_type (void)
 ConnectDialog *
 connect_dialog_new (void)
 {
-	ConnectDialog *dialog = g_object_new (connect_dialog_get_type(), 0);
-	if (dialog->toplevel == NULL) {
-		g_object_unref (dialog);
-		return NULL;
-	}
-	return dialog;
+	return g_object_new (CONNECT_DIALOG_TYPE, 0);
 }
