@@ -1,7 +1,7 @@
 /*
  * pixmaps.c - helper functions for pixmaps
  *
- * Copyright (C) 2004-2006 xchat-gnome team
+ * Copyright (C) 2004-2007 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -26,10 +26,13 @@
 void
 pixmaps_init (void)
 {
+	/* FIXME multi-head! */
 	GtkIconTheme *theme = gtk_icon_theme_get_default ();
 	gchar *uninstalled_path = g_build_filename (TOPSRCDIR, "data", "icons", NULL);
 	if (g_file_test (uninstalled_path, G_FILE_TEST_EXISTS)) {
 		gtk_icon_theme_prepend_search_path (theme, uninstalled_path);
+	} else {
+		gtk_icon_theme_append_search_path (theme, ICONDIR);
 	}
 	g_free (uninstalled_path);
 }
