@@ -1,7 +1,7 @@
 /*
  * preferences-page-irc.c - helpers for the irc preferences page
  *
- * Copyright (C) 2004-2006 xchat-gnome team
+ * Copyright (C) 2004-2007 xchat-gnome team
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,8 +23,15 @@
 #include <glib/gi18n.h>
 #include <string.h>
 #include <gconf/gconf-client.h>
+#include "../common/xchat.h"
+#include "../common/text.h"
+#include "../common/xchatc.h"
 #include "preferences-page-irc.h"
 #include "preferences-dialog.h"
+#include "util.h"
+#include "conversation-panel.h"
+
+G_DEFINE_TYPE(PreferencesPageIrc, preferences_page_irc, PREFERENCES_PAGE_TYPE)
 
 extern struct xchatprefs prefs;
 
@@ -101,13 +108,13 @@ gconf_font_changed (GConfClient *client, guint cnxn_id, GConfEntry *entry, GtkFo
 }
 
 static void
-sysfonts_changed (GtkToggleButton *toggle, PreferencesIrcPage *page)
+sysfonts_changed (GtkToggleButton *toggle, PreferencesPageIrc *page)
 {
 	gtk_widget_set_sensitive (page->font_selection, !gtk_toggle_button_get_active (toggle));
 }
 
 static void
-highlight_selection_changed (GtkTreeSelection *select, PreferencesIrcPage *page)
+highlight_selection_changed (GtkTreeSelection *select, PreferencesPageIrc *page)
 {
 	if (gtk_tree_selection_get_selected (select, NULL, NULL)) {
 		gtk_widget_set_sensitive (page->highlight_edit, TRUE);
@@ -119,7 +126,7 @@ highlight_selection_changed (GtkTreeSelection *select, PreferencesIrcPage *page)
 }
 
 static void
-save_highlight (PreferencesIrcPage *page)
+save_highlight (PreferencesPageIrc *page)
 {
 	GtkTreeIter iter;
 	gchar *highlight, *tmp1, *tmp2;
@@ -127,7 +134,7 @@ save_highlight (PreferencesIrcPage *page)
 		gtk_tree_model_get (GTK_TREE_MODEL (page->highlight_store), &iter, 0, &tmp1, -1);
 		highlight = g_strdup (tmp1);
 	} else {
-		prefs.irc_nick_hilight[0] = '\0';
+		prefs.irc_extra_hilight[0] = '\0';
 		return;
 	}
 	while (gtk_tree_model_iter_next (GTK_TREE_MODEL (page->highlight_store), &iter)) {
@@ -136,12 +143,12 @@ save_highlight (PreferencesIrcPage *page)
 		highlight = g_strdup_printf ("%s,%s", tmp2, tmp1);
 		g_free (tmp2);
 	}
-	strncpy (prefs.irc_nick_hilight, highlight, 300);
+	strncpy (prefs.irc_extra_hilight, highlight, 300);
 	g_free (highlight);
 }
 
 static void
-highlight_add (GtkButton *button, PreferencesIrcPage *page)
+highlight_add (GtkButton *button, PreferencesPageIrc *page)
 {
 	GtkTreeIter iter;
 	GtkTreePath *path;
@@ -153,7 +160,7 @@ highlight_add (GtkButton *button, PreferencesIrcPage *page)
 }
 
 static void
-highlight_edit (GtkButton *button, PreferencesIrcPage *page)
+highlight_edit (GtkButton *button, PreferencesPageIrc *page)
 {
 	GtkTreeSelection *select;
 	GtkTreeIter iter;
@@ -169,7 +176,7 @@ highlight_edit (GtkButton *button, PreferencesIrcPage *page)
 }
 
 static void
-highlight_remove (GtkButton *button, PreferencesIrcPage *page)
+highlight_remove (GtkButton *button, PreferencesPageIrc *page)
 {
 	GtkTreeSelection *select;
 	GtkTreeIter iter;
@@ -183,7 +190,7 @@ highlight_remove (GtkButton *button, PreferencesIrcPage *page)
 }
 
 static void
-highlight_edited (GtkCellRendererText *renderer, gchar *arg1, gchar *newtext, PreferencesIrcPage *page)
+highlight_edited (GtkCellRendererText *renderer, gchar *arg1, gchar *newtext, PreferencesPageIrc *page)
 {
 	GtkTreeSelection *selection;
 	GtkTreeModel *model;
@@ -191,24 +198,82 @@ highlight_edited (GtkCellRendererText *renderer, gchar *arg1, gchar *newtext, Pr
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (page->highlight_list));
 	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
-		if (strlen (newtext))
+		if (strlen (newtext)) {
 			gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, newtext, -1);
-		else
+		} else {
 			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+		}
 		save_highlight (page);
 	}
 }
 
-PreferencesIrcPage *
+static void
+highlight_canceled (GtkCellRendererText *renderer, PreferencesPageIrc *page)
+{
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	gchar *text;
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (page->highlight_list));
+	if (gtk_tree_selection_get_selected (selection, &model, &iter)) {
+		gtk_tree_model_get (GTK_TREE_MODEL (page->highlight_store), &iter, 0, &text, -1);
+		if (text == NULL)
+			gtk_list_store_remove (GTK_LIST_STORE (model), &iter);
+	}
+}
+
+static void
+auto_logging_changed (GtkToggleButton *button, gpointer data)
+{
+	gboolean active;
+	GSList *list;
+	session *sess;
+
+	active = gtk_toggle_button_get_active (button);
+
+	if (active) {
+		prefs.logging = 1;
+	} else {
+		prefs.logging = 0;
+	}
+
+	list = sess_list;
+	while (list) {
+		sess = list->data;
+		if (active) {
+			log_open (sess);
+		} else {
+			log_close (sess);
+		}
+		list = list->next;
+	}
+}
+
+static void
+show_marker_changed (GtkToggleButton *button, gpointer data)
+{
+	gboolean active;
+
+	active = gtk_toggle_button_get_active (button);
+	conversation_panel_set_show_marker (CONVERSATION_PANEL (gui.conversation_panel), active);
+
+	if (active) {
+		prefs.show_marker = 1;
+	} else {
+		prefs.show_marker = 0;
+	}
+}
+
+PreferencesPageIrc*
 preferences_page_irc_new (gpointer prefs_dialog, GladeXML *xml)
 {
-	PreferencesIrcPage *page = g_new0 (PreferencesIrcPage, 1);
+	PreferencesPageIrc *page = g_object_new (PREFERENCES_PAGE_IRC_TYPE, NULL);
 	PreferencesDialog *p = (PreferencesDialog *) prefs_dialog;
 	GtkTreeIter iter;
 	GtkCellRenderer *renderer;
 	gchar *text;
 	gboolean toggle;
-	GtkSizeGroup *group;
 	GtkTreeSelection *select;
 	gchar **highlight_entries;
 	gint i;
@@ -229,25 +294,16 @@ preferences_page_irc_new (gpointer prefs_dialog, GladeXML *xml)
 	GW(usethisfont);
 	GW(font_selection);
 
-	GW(show_colors);
+	GW(auto_logging);
 	GW(show_timestamps);
+	GW(show_marker);
 #undef GW
 
-	if (g_file_test ("../../data/irc.png", G_FILE_TEST_EXISTS))
-		page->icon = gdk_pixbuf_new_from_file ("../../data/irc.png", NULL);
-	else
-		page->icon = gdk_pixbuf_new_from_file (XCHATSHAREDIR "/irc.png", NULL);
-	gtk_list_store_append (p->page_store, &iter);
-	gtk_list_store_set (p->page_store, &iter, 0, page->icon, 1, _("IRC Preferences"), 2, 0, -1);
+	GtkIconTheme *theme = gtk_icon_theme_get_default ();
+	PREFERENCES_PAGE (page)->icon = gtk_icon_theme_load_icon (theme, "preferences-system", 16, 0, NULL);
 
-	group = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (group, page->nick_name);
-	gtk_size_group_add_widget (group, page->real_name);
-	gtk_size_group_add_widget (group, page->quit_message);
-	gtk_size_group_add_widget (group, page->part_message);
-	gtk_size_group_add_widget (group, page->away_message);
-	gtk_size_group_add_widget (group, page->font_selection);
-	g_object_unref (group);
+	gtk_list_store_append (p->page_store, &iter);
+	gtk_list_store_set (p->page_store, &iter, 0, PREFERENCES_PAGE (page)->icon, 1, _("IRC Preferences"), 2, 0, -1);
 
 	g_signal_connect (G_OBJECT (page->nick_name),        "changed",  G_CALLBACK (entry_changed),    "/apps/xchat/irc/nickname");
 	g_signal_connect (G_OBJECT (page->real_name),        "changed",  G_CALLBACK (entry_changed),    "/apps/xchat/irc/realname");
@@ -257,8 +313,9 @@ preferences_page_irc_new (gpointer prefs_dialog, GladeXML *xml)
 	g_signal_connect (G_OBJECT (page->usesysfonts),      "toggled",  G_CALLBACK (bool_changed),     "/apps/xchat/main_window/use_sys_fonts");
 	g_signal_connect (G_OBJECT (page->usesysfonts),      "toggled",  G_CALLBACK (sysfonts_changed), page);
 	g_signal_connect (G_OBJECT (page->font_selection),   "font-set", G_CALLBACK (font_changed),     "/apps/xchat/main_window/font");
-	g_signal_connect (G_OBJECT (page->show_colors),      "toggled",  G_CALLBACK (bool_changed),     "/apps/xchat/irc/showcolors");
 	g_signal_connect (G_OBJECT (page->show_timestamps),  "toggled",  G_CALLBACK (bool_changed),     "/apps/xchat/irc/showtimestamps");
+	g_signal_connect (G_OBJECT (page->auto_logging),     "toggled",  G_CALLBACK (auto_logging_changed), NULL);
+	g_signal_connect (G_OBJECT (page->show_marker),      "toggled",  G_CALLBACK (show_marker_changed), NULL);
 	g_signal_connect (G_OBJECT (page->highlight_add),    "clicked",  G_CALLBACK (highlight_add),    page);
 	g_signal_connect (G_OBJECT (page->highlight_edit),   "clicked",  G_CALLBACK (highlight_edit),   page);
 	g_signal_connect (G_OBJECT (page->highlight_remove), "clicked",  G_CALLBACK (highlight_remove), page);
@@ -270,28 +327,47 @@ preferences_page_irc_new (gpointer prefs_dialog, GladeXML *xml)
 	page->nh[4] = gconf_client_notify_add (p->gconf, "/apps/xchat/irc/awaymsg",               (GConfClientNotifyFunc) gconf_entry_changed, page->away_message,    NULL, NULL);
 	page->nh[5] = gconf_client_notify_add (p->gconf, "/apps/xchat/main_window/use_sys_fonts", (GConfClientNotifyFunc) gconf_bool_changed,  page->usesysfonts,     NULL, NULL);
 	page->nh[6] = gconf_client_notify_add (p->gconf, "/apps/xchat/main-window/font",          (GConfClientNotifyFunc) gconf_font_changed,  page->font_selection,  NULL, NULL);
-	page->nh[7] = gconf_client_notify_add (p->gconf, "/apps/xchat/irc/showcolors",            (GConfClientNotifyFunc) gconf_bool_changed,  page->show_colors,     NULL, NULL);
-	page->nh[8] = gconf_client_notify_add (p->gconf, "/apps/xchat/irc/showtimestamps",        (GConfClientNotifyFunc) gconf_bool_changed,  page->show_timestamps, NULL, NULL);
+	page->nh[7] = gconf_client_notify_add (p->gconf, "/apps/xchat/irc/showtimestamps",        (GConfClientNotifyFunc) gconf_bool_changed,  page->show_timestamps, NULL, NULL);
 
 	text = gconf_client_get_string (p->gconf, "/apps/xchat/irc/nickname", NULL);
-	gtk_entry_set_text (GTK_ENTRY (page->nick_name), text);
-	g_free (text);
+	if (text) {
+		gtk_entry_set_text (GTK_ENTRY (page->nick_name), text);
+		g_free (text);
+	} else {
+		gtk_entry_set_text (GTK_ENTRY (page->nick_name), "");
+	}
 
 	text = gconf_client_get_string (p->gconf, "/apps/xchat/irc/realname", NULL);
-	gtk_entry_set_text (GTK_ENTRY (page->real_name), text);
-	g_free (text);
+	if (text) {
+		gtk_entry_set_text (GTK_ENTRY (page->real_name), text);
+		g_free (text);
+	} else {
+		gtk_entry_set_text (GTK_ENTRY (page->real_name), "");
+	}
 
 	text = gconf_client_get_string (p->gconf, "/apps/xchat/irc/quitmsg", NULL);
-	gtk_entry_set_text (GTK_ENTRY (page->quit_message), text);
-	g_free (text);
+	if (text) {
+		gtk_entry_set_text (GTK_ENTRY (page->quit_message), text);
+		g_free (text);
+	} else {
+		gtk_entry_set_text (GTK_ENTRY (page->quit_message), "");
+	}
 
 	text = gconf_client_get_string (p->gconf, "/apps/xchat/irc/partmsg", NULL);
-	gtk_entry_set_text (GTK_ENTRY (page->part_message), text);
-	g_free (text);
+	if (text) {
+		gtk_entry_set_text (GTK_ENTRY (page->part_message), text);
+		g_free (text);
+	} else {
+		gtk_entry_set_text (GTK_ENTRY (page->part_message), "");
+	}
 
 	text = gconf_client_get_string (p->gconf, "/apps/xchat/irc/awaymsg", NULL);
-	gtk_entry_set_text (GTK_ENTRY (page->away_message), text);
-	g_free (text);
+	if (text) {
+		gtk_entry_set_text (GTK_ENTRY (page->away_message), text);
+		g_free (text);
+	} else {
+		gtk_entry_set_text (GTK_ENTRY (page->away_message), "");
+	}
 
 	toggle = gconf_client_get_bool (p->gconf, "/apps/xchat/main_window/use_sys_fonts", NULL);
 	if (toggle)
@@ -301,15 +377,16 @@ preferences_page_irc_new (gpointer prefs_dialog, GladeXML *xml)
 	gtk_widget_set_sensitive (page->font_selection, !toggle);
 
 	text = gconf_client_get_string (p->gconf, "/apps/xchat/main_window/font", NULL);
-	gtk_font_button_set_font_name (GTK_FONT_BUTTON (page->font_selection), text);
-	g_free (text);
-
-	toggle = gconf_client_get_bool (p->gconf, "/apps/xchat/irc/showcolors", NULL);
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (page->show_colors), toggle);
+	if (text) {
+		gtk_font_button_set_font_name (GTK_FONT_BUTTON (page->font_selection), text);
+		g_free (text);
+	}
 
 	toggle = gconf_client_get_bool (p->gconf, "/apps/xchat/irc/showtimestamps", NULL);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (page->show_timestamps), toggle);
 
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (page->auto_logging), prefs.logging);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (page->show_marker), prefs.show_marker);
 	/* highlight list */
 	page->highlight_store = gtk_list_store_new (1, G_TYPE_STRING);
 	gtk_tree_view_set_model (GTK_TREE_VIEW (page->highlight_list), GTK_TREE_MODEL (page->highlight_store));
@@ -322,8 +399,9 @@ preferences_page_irc_new (gpointer prefs_dialog, GladeXML *xml)
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (page->highlight_list));
 	g_signal_connect (G_OBJECT (select), "changed", G_CALLBACK (highlight_selection_changed), page);
 	g_signal_connect (G_OBJECT (renderer), "edited", G_CALLBACK (highlight_edited), page);
+	g_signal_connect (G_OBJECT (renderer), "editing-canceled", G_CALLBACK (highlight_canceled), page);
 
-	highlight_entries = g_strsplit (prefs.irc_nick_hilight, ",", 0);
+	highlight_entries = g_strsplit (prefs.irc_extra_hilight, ",", 0);
 	for (i = 0; highlight_entries[i]; i++) {
 		gtk_list_store_append (page->highlight_store, &iter);
 		gtk_list_store_set (page->highlight_store, &iter, 0, highlight_entries[i], -1);
@@ -333,18 +411,47 @@ preferences_page_irc_new (gpointer prefs_dialog, GladeXML *xml)
 	return page;
 }
 
-void
-preferences_page_irc_free (PreferencesIrcPage *page)
+static void
+preferences_page_irc_init (PreferencesPageIrc *page)
 {
+}
+
+static void
+preferences_page_irc_dispose (GObject *object)
+{
+	PreferencesPageIrc *page = (PreferencesPageIrc *) object;
+
+	if (page->highlight_store)
+	{
+		g_object_unref (page->highlight_store);
+		page->highlight_store = NULL;
+	}
+
+	G_OBJECT_CLASS (preferences_page_irc_parent_class)->dispose (object);
+}
+
+static void
+preferences_page_irc_finalize (GObject *object)
+{
+	PreferencesPageIrc *page = (PreferencesPageIrc *) object;
 	gint i;
 	GConfClient *client;
 
 	client = gconf_client_get_default ();
-	for (i = 0; i < 9; i++)
+	for (i = 0; i < 8; i++) {
 		gconf_client_notify_remove (client, page->nh[i]);
+	}
+
 	g_object_unref (client);
 
-	g_object_unref (page->highlight_store);
-	g_object_unref (page->icon);
-	g_free (page);
+	G_OBJECT_CLASS (preferences_page_irc_parent_class)->finalize (object);
+}
+
+static void
+preferences_page_irc_class_init (PreferencesPageIrcClass *klass)
+{
+	GObjectClass *object_class = (GObjectClass *) klass;
+
+	object_class->dispose = preferences_page_irc_dispose;
+	object_class->finalize = preferences_page_irc_finalize;
 }
